@@ -1,14 +1,13 @@
-from django.conf.urls import url
 from django.contrib.staticfiles.urls import staticfiles_urlpatterns
 from django.contrib import admin
 from django.conf import settings
-from django.urls import path
+from django.urls import re_path
 
 
 admin.autodiscover()
 
 urlpatterns = [
-    path('admin/', admin.site.urls),
+    re_path('admin/', admin.site.urls),
 ]
 
 if settings.DEBUG:
